# TokenValidity

Token validity

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**start** | **datetime** | The start time for when the token is valid | [optional] 
**duration** | **int** | The duration of time in seconds for which the token is valid | [optional] 
**end** | **datetime** | The end time for when the token is valid | [optional] 
**does_not_expire** | **bool** | If true, this token does not expire. | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


